@@ -1,5 +1,5 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2009 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: ike-scan.h 9884 2007-01-14 19:05:39Z rsh $
+ * $Id$
  *
  * ike-scan.h -- Header file for IKE Scanner (ike-scan)
  *
@@ -84,10 +84,6 @@
 #include <netdb.h>
 #endif
 
-#ifdef HAVE_SYSLOG_H
-#include <syslog.h>
-#endif
-
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #else
@@ -183,8 +179,6 @@
 #define DEFAULT_PROTOCOL PROTO_ISAKMP	/* Default Proposal Protocol */
 #define DEFAULT_TRANS_ID KEY_IKE	/* Default Transform ID */
 #define DEFAULT_IKE_VERSION 1		/* Default IKE version */
-#define SYSLOG 1			/* Use syslog if defined */
-#define SYSLOG_FACILITY LOG_USER	/* Syslog facility to use */
 #define PATTERNS_FILE "ike-backoff-patterns" /* Backoff patterns filename */
 #define VID_FILE "ike-vendor-ids"	/* Vendor ID patterns filename */
 #define REALLOC_COUNT	1000		/* Entries to realloc at once */
@@ -331,17 +325,23 @@ typedef struct {	/* IKE Packet Parameters */
 
 /* Functions */
 
+#ifndef HAVE_STRLCAT
+size_t strlcat(char *dst, const char *src, size_t siz);
+#endif
+#ifndef HAVE_STRLCPY
+size_t strlcpy(char *dst, const char *src, size_t siz);
+#endif
+
 void err_sys(const char *, ...);
 void warn_sys(const char *, ...);
 void err_msg(const char *, ...);
 void warn_msg(const char *, ...);
-void info_syslog(const char *, ...);
-void err_print(int, int, const char *, va_list);
+void err_print(int, const char *, va_list);
 void usage(int, int);
 void add_host_pattern(const char *, unsigned, unsigned *, unsigned char *,
                       size_t);
 void add_host(const char *, unsigned, unsigned *, unsigned char *,
-              size_t);
+              size_t, int);
 void send_packet(int, unsigned char *, size_t, host_entry *, unsigned, unsigned,
                  struct timeval *);
 int recvfrom_wto(int, unsigned char *, size_t, struct sockaddr *, int);
@@ -403,6 +403,7 @@ int Gettimeofday(struct timeval *);
 void *Malloc(size_t);
 void *Realloc(void *, size_t);
 unsigned long int Strtoul(const char *, int);
+long int Strtol(const char *, int);
 void decode_trans_simple(const char *, unsigned *, unsigned *, unsigned *,
                          unsigned *, unsigned *);
 unsigned char *decode_transform(const char *, size_t *);
@@ -446,6 +447,9 @@ uint8_t random_byte(void);
 uint32_t random_ip(void);
 int str_ccmp(const char *, const char *);
 unsigned name_or_number(const char *, const id_name_map[]);
+unsigned str_to_bandwidth(const char *);
+unsigned str_to_interval(const char *);
+char *dupstr(const char *);
 /* MT19937 prototypes */
 void init_genrand(unsigned long);
 void init_by_array(unsigned long[], int);
