@@ -33,7 +33,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: isakmp.c 9884 2007-01-14 19:05:39Z rsh $
+ * $Id$
  *
  * Author: Roy Hills
  * Date: 7 November 2003
@@ -44,7 +44,7 @@
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id: isakmp.c 9884 2007-01-14 19:05:39Z rsh $";	/* RCS ID for ident(1) */
+static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
 
 const id_name_map notification_map[] = { /* From RFC 2408 3.14.1 */
    {0, "UNSPECIFIED"},
@@ -204,7 +204,11 @@ const id_name_map auth_map[] = {	/* From RFC 2409 App. A */
    {8, "ECDSA_Sig"},
    {128, "CRACK"},	/* From draft-harkins-ipsra-crack-00 */
    {64221, "Hybrid"},
-   {65001, "XAUTH"},
+   {65001, "XAUTH_PSK"},
+   {65003, "XAUTH_DSS"},
+   {65005, "XAUTH_RSA"},
+   {65007, "XAUTH_RSA_Enc"},
+   {65009, "XAUTH_RSA_RevEnc"},
    {-1, NULL}
 };
 const id_name_map integ_map[] = {	/* From RFC 4306 3.3.2 */
@@ -588,7 +592,7 @@ make_prop(size_t *outlen, unsigned next, unsigned number, unsigned notrans,
 /* If the SPI size is non-zero, add a random SPI of the specified length */
 
    if (spi_size > 0) {
-      int i;
+      unsigned i;
 
       for (i=0; i<spi_size; i++)
          *(cp++) = (unsigned char) random_byte();
