@@ -33,7 +33,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: psk-crack.c 9919 2007-01-22 22:52:36Z rsh $
+ * $Id$
  *
  * psk-crack.c -- IKE Aggressive Mode Pre-Shared Key cracker for ike-scan
  *
@@ -47,7 +47,7 @@
 #include "psk-crack.h"
 #include "hash_functions.h"
 
-static const char rcsid[] = "$Id: psk-crack.c 9919 2007-01-22 22:52:36Z rsh $";	/* RCS ID for ident(1) */
+static const char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
 
 static const char *default_charset =
    "0123456789abcdefghijklmnopqrstuvwxyz"; /* default bruteforce charset */
@@ -80,7 +80,7 @@ main (int argc, char *argv[]) {
    struct timeval end_time;	/* Program end time */
    struct timeval elapsed_time; /* Elapsed time as timeval */
    double elapsed_seconds;	/* Elapsed time in seconds */
-   int psk_idx;			/* Index into psk list */
+   unsigned psk_idx;		/* Index into psk list */
    unsigned psk_count;		/* Number of PSK entries in the list */
    unsigned psk_uncracked;	/* Number of uncracked PSK entries */
    unsigned char *hash_r;
@@ -120,7 +120,7 @@ main (int argc, char *argv[]) {
             charset=make_message("%s", optarg);
             break;
          case 'd':      /* --dictionary */
-            strncpy(dict_file_name, optarg, MAXLINE);
+            strlcpy(dict_file_name, optarg, sizeof(dict_file_name));
             brute_len = 0;
             break;
          case 'u':      /* --norteluser */
@@ -420,7 +420,7 @@ load_psk_params(const char *filename, const char *nortel_user) {
       pe->hash_r = hex2data(hash_r_hex, &pe->hash_r_len);
       hash_r_hex_len = strlen(hash_r_hex) + 1;	/* includes terminating null */
       pe->hash_r_hex = Malloc(hash_r_hex_len);
-      strncpy(pe->hash_r_hex, hash_r_hex, hash_r_hex_len);
+      strlcpy(pe->hash_r_hex, hash_r_hex, hash_r_hex_len);
       pe->nortel_user = nortel_user;
 /*
  *	Determine hash type based on the length of the hash, and
