@@ -1,5 +1,5 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2009 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This program is free software; you can redistribute it and/or
@@ -33,20 +33,17 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: utils.c 9884 2007-01-14 19:05:39Z rsh $
+ * $Id$
  *
  * Author: Roy Hills
  * Date: 5 April 2004
  *
  * This file contains various utility functions used by ike-scan.
- *
- * These functions were originally in ike-scan.c, but were moved to utils.c
- * because ike-scan.c was getting rather large.
  */
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id: utils.c 9884 2007-01-14 19:05:39Z rsh $";	/* RCS ID for ident(1) */
+static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
 
 
 /*
@@ -105,7 +102,7 @@ timeval_diff(const struct timeval *a, const struct timeval *b,
 int
 times_close_enough(struct timeval *t1, struct timeval *t2, unsigned fuzz) {
 struct timeval diff;
-int diff_ms;
+unsigned diff_ms;
 
    timeval_diff(t1, t2, &diff);	/* diff = t1 - t2 */
    diff_ms = abs(1000*diff.tv_sec + diff.tv_usec/1000);
@@ -207,7 +204,7 @@ hex2data(const char *string, size_t *data_len) {
  *
  *	The returned pointer points to malloc'ed storage which should be
  *	free'ed by the caller when it's no longer needed.  If the length of
- *	the inputs string is not even, the function will return NULL and
+ *	the input string is not even, the function will return NULL and
  *	set data_len to 0.
  */
 unsigned char *
@@ -249,12 +246,14 @@ hex_or_str(const char *string, size_t *data_len) {
  *	0x<hex-data>	Input is in hex format
  *	decimal number	Input is in numeric format
  *
- *	For numeric input, the binary data will be a 32-bit value in
+ *	For hex input format, the binary data will have the length required
+ *	to hold the specified value. For numeric input, the binary data will
+ *	be a 32-bit value.  In either case, the binary data will be in
  *	big endian format.
  *
  *	The returned pointer points to malloc'ed storage which should be
  *	free'ed by the caller when it's no longer needed.  If the length of
- *	the inputs string is not even, the function will return NULL and
+ *	the input string is not even, the function will return NULL and
  *	set data_len to 0.
  */
 unsigned char *
@@ -311,7 +310,7 @@ make_message(const char *fmt, ...) {
       n = vsnprintf (p, size, fmt, ap);
       va_end(ap);
       /* If that worked, return the string. */
-      if (n > -1 && n < size)
+      if (n > -1 && n < (int) size)
          return p;
       /* Else try again with more space. */
       if (n > -1)    /* glibc 2.1 */
@@ -499,7 +498,7 @@ hexstring(const unsigned char *data, size_t size) {
    cp = data;
    r = result;
    for (i=0; i<size; i++) {
-      sprintf(r, "%.2x", *cp++);
+      snprintf(r, 3, "%.2x", *cp++);
       r += 2;
    }
    *r = '\0';
@@ -568,7 +567,7 @@ print_times(void) {
  *	It doesn't perform any processing; it merely returns to
  *	interrupt the current system call.
  */
-void sig_alarm(int signo) {
+void sig_alarm(int signo ATTRIBUTE_UNUSED) {
    return;      /* just interrupt the current system call */
 }
 
@@ -599,7 +598,7 @@ id_to_name(unsigned id, const id_name_map map[]) {
       return NULL;
 
    while (map[i].id != -1) {
-      if (id == map[i].id) {
+      if (id == (unsigned)map[i].id) {
          found = 1;
          break;
       }
@@ -808,6 +807,122 @@ name_or_number(const char *string, const id_name_map map[]) {
    return result;
 }
 
+/*
+ *	str_to_bandwidth -- Convert a bandwidth string to unsigned integer
+ *
+ *	Inputs:
+ *
+ *	bandwidth_string	The bandwidth string to convert
+ *
+ *	Returns:
+ *
+ *	The bandwidth in bits per second as an unsigned integer
+ */
+unsigned
+str_to_bandwidth(const char *bandwidth_string) {
+   char *bandwidth_str;
+   size_t bandwidth_len;
+   unsigned value;
+   int multiplier=1;
+   int end_char;
+
+   bandwidth_str=dupstr(bandwidth_string);	/* Writable copy */
+   bandwidth_len=strlen(bandwidth_str);
+   end_char = bandwidth_str[bandwidth_len-1];
+   if (!isdigit(end_char)) {	/* End character is not a digit */
+      bandwidth_str[bandwidth_len-1] = '\0';	/* Remove last character */
+      switch (end_char) {
+         case 'M':
+         case 'm':
+            multiplier = 1000000;
+            break;
+         case 'K':
+         case 'k':
+            multiplier = 1000;
+            break;
+         default:
+            err_msg("ERROR: Unknown bandwidth multiplier character: \"%c\"",
+                    end_char);
+            break;
+      }
+   }
+   value=Strtoul(bandwidth_str, 10);
+   free(bandwidth_str);
+   return multiplier * value;
+}
+
+/*
+ *	str_to_interval -- Convert an interval string to unsigned integer
+ *
+ *	Inputs:
+ *
+ *	interval_string		The interval string to convert
+ *
+ *	Returns:
+ *
+ *	The interval in microsecons as an unsigned integer
+ */
+unsigned
+str_to_interval(const char *interval_string) {
+   char *interval_str;
+   size_t interval_len;
+   unsigned value;
+   int multiplier=1000;
+   int end_char;
+
+   interval_str=dupstr(interval_string);	/* Writable copy */
+   interval_len=strlen(interval_str);
+   end_char = interval_str[interval_len-1];
+   if (!isdigit(end_char)) {	/* End character is not a digit */
+      interval_str[interval_len-1] = '\0';	/* Remove last character */
+      switch (end_char) {
+         case 'U':
+         case 'u':
+            multiplier = 1;
+            break;
+         case 'S':
+         case 's':
+            multiplier = 1000000;
+            break;
+         default:
+            err_msg("ERROR: Unknown interval multiplier character: \"%c\"",
+                    end_char);
+            break;
+      }
+   }
+   value=Strtoul(interval_str, 10);
+   free(interval_str);
+   return multiplier * value;
+}
+
+/*
+ *	dupstr -- duplicate a string
+ *
+ *	Inputs:
+ *
+ *	str	The string to duplcate
+ *
+ *	Returns:
+ *
+ *	A pointer to the duplicate string.
+ *
+ *	This is a replacement for the common but non-standard "strdup"
+ *	function.
+ *
+ *	The returned pointer points to Malloc'ed memory, which must be
+ *	free'ed by the caller.
+ */
+char *
+dupstr(const char *str) {
+   char *cp;
+   size_t len;
+
+   len = strlen(str) + 1;	/* Allow space for terminating NULL */
+   cp = Malloc(len);
+   strlcpy(cp, str, len);
+   return cp;
+}
+
 void utils_use_rcsid(void) {
    fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
 }
