@@ -1,5 +1,5 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2009 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: wrappers.c 9884 2007-01-14 19:05:39Z rsh $
+ * $Id$
  *
  * Author: Roy Hills
  * Date: 8 November 2003
@@ -52,7 +52,7 @@
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id: wrappers.c 9884 2007-01-14 19:05:39Z rsh $";	/* RCS ID for ident(1) */
+static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
 
 /*
  * We omit the timezone arg from this wrapper since it's obsolete and we never
@@ -98,6 +98,21 @@ unsigned long int Strtoul(const char *nptr, int base) {
    result=strtoul(nptr, &endptr, base);
    if (endptr == nptr)	/* No digits converted */
       err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
+   if (*endptr != '\0' && !isspace((unsigned char)*endptr))
+      err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
+
+   return result;
+}
+
+long int Strtol(const char *nptr, int base) {
+   char *endptr;
+   long int result;
+
+   result=strtol(nptr, &endptr, base);
+   if (endptr == nptr)	/* No digits converted */
+      err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
+   if (*endptr != '\0' && !isspace((unsigned char)*endptr))
+      err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
 
    return result;
 }
